{
    "$graph": [
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "brianyee/samtools:1.6"
                }
            ],
            "baseCommand": [
                "samtools",
                "view"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3
                    },
                    "label": "BAM file",
                    "id": "#calculate_readnum.cwl/bamFile"
                },
                {
                    "type": "boolean",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-c"
                    },
                    "default": true,
                    "label": "Print only the count",
                    "id": "#calculate_readnum.cwl/countFlag"
                },
                {
                    "type": "int",
                    "inputBinding": {
                        "position": 2,
                        "prefix": "-F"
                    },
                    "default": 4,
                    "label": "Flag to count only the mapped reads",
                    "id": "#calculate_readnum.cwl/readFlag"
                }
            ],
            "stdout": "$(inputs.bamFile.nameroot).readnum",
            "doc": "returns the number of reads inside a *.readnum file\n",
            "id": "#calculate_readnum.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.bamFile.nameroot).readnum"
                    },
                    "id": "#calculate_readnum.cwl/readnum"
                }
            ]
        },
        {
            "doc": "This tool wraps compress_l2foldenrpeakfi_for_replicate_overlapping_bedformat_outputfull.pl,\nwhich merges neighboring or overlapping regions in a BED file.\n  Usage:   perl compress_l2foldenrpeakfi_for_replicate_overlapping_bedformat.pl <in.bed> <out.compressed.bed>\n",
            "class": "CommandLineTool",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "brianyee/merge_peaks:0.1.0"
                }
            ],
            "baseCommand": [
                "compress_l2foldenrpeakfi_for_replicate_overlapping_bedformat_outputfull.pl"
            ],
            "arguments": [
                "$(inputs.input_full.nameroot).compressed.bed",
                "$(inputs.input_full.nameroot).compressed.bed.full"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -1
                    },
                    "id": "#compress_l2foldenrpeakfi_for_replicate_overlapping_bedformat_outputfull.cwl/input_full"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_full.nameroot).compressed.bed"
                    },
                    "id": "#compress_l2foldenrpeakfi_for_replicate_overlapping_bedformat_outputfull.cwl/output_bed"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.input_full.nameroot).compressed.bed.full"
                    },
                    "id": "#compress_l2foldenrpeakfi_for_replicate_overlapping_bedformat_outputfull.cwl/output_full"
                }
            ],
            "id": "#compress_l2foldenrpeakfi_for_replicate_overlapping_bedformat_outputfull.cwl"
        },
        {
            "doc": "Converts a full file into a bed6 formatted file.\n",
            "class": "CommandLineTool",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "brianyee/merge_peaks:0.1.0"
                }
            ],
            "baseCommand": [
                "full_to_bed.py"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1,
                        "prefix": "--input"
                    },
                    "id": "#full_to_bed.cwl/full"
                }
            ],
            "arguments": [
                "--output",
                "$(inputs.full.nameroot).bed"
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.full.nameroot).bed"
                    },
                    "id": "#full_to_bed.cwl/bed"
                }
            ],
            "id": "#full_to_bed.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "coresMin": 1,
                    "ramMin": 16000
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "brianyee/merge_peaks:0.1.0"
                }
            ],
            "baseCommand": [
                "make_informationcontent_from_peaks.pl"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 2
                    },
                    "doc": "A file containing a single number corresponding to the number of mapped reads (-cF 4) in CLIP",
                    "id": "#make_informationcontent_from_peaks.cwl/clip_read_num"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#make_informationcontent_from_peaks.cwl/compressed_bed_full"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 3
                    },
                    "doc": "A file containing a single number corresponding to the number of mapped reads (-cF 4) in INPUT",
                    "id": "#make_informationcontent_from_peaks.cwl/input_read_num"
                },
                {
                    "type": "string",
                    "default": "",
                    "inputBinding": {
                        "position": 5,
                        "valueFrom": "${\n  if (inputs.output_excess_reads == \"\") {\n    return inputs.compressed_bed_full.nameroot + \".entropy.excessreads\";\n  }\n  else {\n    return inputs.output_excess_reads;\n  }\n}\n"
                    },
                    "id": "#make_informationcontent_from_peaks.cwl/output_excess_reads"
                },
                {
                    "type": "string",
                    "default": "",
                    "inputBinding": {
                        "position": 4,
                        "valueFrom": "${\n  if (inputs.output_file == \"\") {\n    return inputs.compressed_bed_full.nameroot + \".entropy.full\";\n  }\n  else {\n    return inputs.output_file;\n  }\n}\n"
                    },
                    "id": "#make_informationcontent_from_peaks.cwl/output_file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n  if (inputs.output_excess_reads == \"\") {\n    return inputs.compressed_bed_full.nameroot + \".entropy.excessreads\";\n  }\n  else {\n    return inputs.output_excess_reads;\n  }\n}"
                    },
                    "id": "#make_informationcontent_from_peaks.cwl/entropy_excess_reads"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n  if (inputs.output_file == \"\") {\n    return inputs.compressed_bed_full.nameroot + \".entropy.full\";\n  }\n  else {\n    return inputs.output_file;\n  }\n}\n"
                    },
                    "id": "#make_informationcontent_from_peaks.cwl/entropy_full"
                }
            ],
            "id": "#make_informationcontent_from_peaks.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "brianyee/merge_peaks:0.1.0"
                }
            ],
            "baseCommand": [
                "overlap_peakfi_with_bam.pl"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -5
                    },
                    "id": "#overlap_peakfi_with_bam.cwl/clipBamFile"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -2
                    },
                    "id": "#overlap_peakfi_with_bam.cwl/clipReadnum"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -4
                    },
                    "id": "#overlap_peakfi_with_bam.cwl/inputBamFile"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -1
                    },
                    "id": "#overlap_peakfi_with_bam.cwl/inputReadnum"
                },
                {
                    "type": "string",
                    "default": "",
                    "inputBinding": {
                        "position": 0,
                        "valueFrom": "${\n  if (inputs.outputFile == \"\") {\n    return inputs.peakFile.nameroot + \".normed.bed\";\n  }\n  else {\n    return inputs.outputFile;\n  }\n}\n"
                    },
                    "id": "#overlap_peakfi_with_bam.cwl/outputFile"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": -3
                    },
                    "id": "#overlap_peakfi_with_bam.cwl/peakFile"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n  if (inputs.outputFile == \"\") {\n    return inputs.peakFile.nameroot + \".normed.bed\";\n  }\n  else {\n    return inputs.outputFile;\n  }\n}\n"
                    },
                    "id": "#overlap_peakfi_with_bam.cwl/inputnormedBed"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "${\n  if (inputs.outputFile == \"\") {\n    return inputs.peakFile.nameroot + \".normed.bed.full\";\n  }\n  else {\n    return inputs.outputFile;\n  }\n}\n"
                    },
                    "id": "#overlap_peakfi_with_bam.cwl/inputnormedBedfull"
                }
            ],
            "doc": "This tool wraps overlap_peakfi_with_bam_PE.pl\n  Usage:\n",
            "id": "#overlap_peakfi_with_bam.cwl"
        },
        {
            "doc": "This workflow normalizes clip aligned reads against a size-matched input\nsample. Then, an entropy score is calculated for each peak found.\n",
            "class": "Workflow",
            "inputs": [
                {
                    "type": "File",
                    "id": "#main/clip_bam_file"
                },
                {
                    "type": "File",
                    "id": "#main/input_bam_file"
                },
                {
                    "type": "File",
                    "id": "#main/peak_file"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/calculate_clip_readnum/readnum",
                    "id": "#main/clip_read_num"
                },
                {
                    "type": "File",
                    "outputSource": "#main/compress_peaks/output_bed",
                    "id": "#main/compressed_bed"
                },
                {
                    "type": "File",
                    "outputSource": "#main/compress_peaks/output_full",
                    "id": "#main/compressed_full"
                },
                {
                    "type": "File",
                    "outputSource": "#main/create_entropybed_from_entropyfull/bed",
                    "id": "#main/entropy_bed"
                },
                {
                    "type": "File",
                    "outputSource": "#main/make_informationcontent_from_peaks/entropy_excess_reads",
                    "id": "#main/entropy_excess_reads"
                },
                {
                    "type": "File",
                    "outputSource": "#main/make_informationcontent_from_peaks/entropy_full",
                    "id": "#main/entropy_full"
                },
                {
                    "type": "File",
                    "outputSource": "#main/input_norm/inputnormedBed",
                    "id": "#main/input_normed_bed"
                },
                {
                    "type": "File",
                    "outputSource": "#main/input_norm/inputnormedBedfull",
                    "id": "#main/input_normed_full"
                },
                {
                    "type": "File",
                    "outputSource": "#main/calculate_input_readnum/readnum",
                    "id": "#main/input_read_num"
                }
            ],
            "steps": [
                {
                    "run": "#calculate_readnum.cwl",
                    "in": [
                        {
                            "source": "#main/clip_bam_file",
                            "id": "#main/calculate_clip_readnum/bamFile"
                        }
                    ],
                    "out": [
                        "#main/calculate_clip_readnum/readnum"
                    ],
                    "id": "#main/calculate_clip_readnum"
                },
                {
                    "run": "#calculate_readnum.cwl",
                    "in": [
                        {
                            "source": "#main/input_bam_file",
                            "id": "#main/calculate_input_readnum/bamFile"
                        }
                    ],
                    "out": [
                        "#main/calculate_input_readnum/readnum"
                    ],
                    "id": "#main/calculate_input_readnum"
                },
                {
                    "run": "#compress_l2foldenrpeakfi_for_replicate_overlapping_bedformat_outputfull.cwl",
                    "in": [
                        {
                            "source": "#main/input_norm/inputnormedBedfull",
                            "id": "#main/compress_peaks/input_full"
                        }
                    ],
                    "out": [
                        "#main/compress_peaks/output_bed",
                        "#main/compress_peaks/output_full"
                    ],
                    "id": "#main/compress_peaks"
                },
                {
                    "run": "#full_to_bed.cwl",
                    "in": [
                        {
                            "source": "#main/make_informationcontent_from_peaks/entropy_full",
                            "id": "#main/create_entropybed_from_entropyfull/full"
                        }
                    ],
                    "out": [
                        "#main/create_entropybed_from_entropyfull/bed"
                    ],
                    "id": "#main/create_entropybed_from_entropyfull"
                },
                {
                    "run": "#overlap_peakfi_with_bam.cwl",
                    "in": [
                        {
                            "source": "#main/clip_bam_file",
                            "id": "#main/input_norm/clipBamFile"
                        },
                        {
                            "source": "#main/calculate_clip_readnum/readnum",
                            "id": "#main/input_norm/clipReadnum"
                        },
                        {
                            "source": "#main/input_bam_file",
                            "id": "#main/input_norm/inputBamFile"
                        },
                        {
                            "source": "#main/calculate_input_readnum/readnum",
                            "id": "#main/input_norm/inputReadnum"
                        },
                        {
                            "source": "#main/peak_file",
                            "id": "#main/input_norm/peakFile"
                        }
                    ],
                    "out": [
                        "#main/input_norm/inputnormedBed",
                        "#main/input_norm/inputnormedBedfull"
                    ],
                    "id": "#main/input_norm"
                },
                {
                    "run": "#make_informationcontent_from_peaks.cwl",
                    "in": [
                        {
                            "source": "#main/calculate_clip_readnum/readnum",
                            "id": "#main/make_informationcontent_from_peaks/clip_read_num"
                        },
                        {
                            "source": "#main/compress_peaks/output_full",
                            "id": "#main/make_informationcontent_from_peaks/compressed_bed_full"
                        },
                        {
                            "source": "#main/calculate_input_readnum/readnum",
                            "id": "#main/make_informationcontent_from_peaks/input_read_num"
                        }
                    ],
                    "out": [
                        "#main/make_informationcontent_from_peaks/entropy_full",
                        "#main/make_informationcontent_from_peaks/entropy_excess_reads"
                    ],
                    "id": "#main/make_informationcontent_from_peaks"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
